@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1301';
+our $VERSION = '0.1400';
 
 use Moo;
 use strictures 2;
@@ -102,12 +102,20 @@ has emotion => (
 );
 
 
+has familiarity => (
+    is       => 'rw',
+    init_arg => undef,
+    default  => sub { { known => 0, unknown => 0 } },
+);
+
+
 sub analyze {
     my ($self) = @_;
 
     my @sentences = $self->_get_sentences();
 
     my @scores;
+    my ( $known, $unknown ) = ( 0, 0 );
 
     for my $sentence ( @sentences ) {
         my @words = _tokenize($sentence);
@@ -117,13 +125,24 @@ sub analyze {
         for my $word ( @words ) {
             $word = $self->_stemword($word);
 
-            $score += exists $self->positive->wordlist->{$word} ? 1
-                    : exists $self->negative->wordlist->{$word} ? -1 : 0;
+            my $value = exists $self->positive->wordlist->{$word} ? 1
+                : exists $self->negative->wordlist->{$word} ? -1 : 0;
+
+            if ( $value ) {
+                $known++;
+            }
+            else {
+                $unknown++;
+            }
+
+            $score += $value;
         }
 
         push @scores, $score;
     }
 
+    $self->familiarity( { known => $known, unknown => $unknown } );
+
     $self->scores( \@scores );
 }
 
@@ -153,6 +172,7 @@ sub nrc_sentiment {
     my @sentences = $self->_get_sentences();
 
     my @scores;
+    my ( $known, $unknown ) = ( 0, 0 );
 
     for my $sentence ( @sentences ) {
         my @words = _tokenize($sentence);
@@ -163,10 +183,15 @@ sub nrc_sentiment {
             $word = $self->_stemword($word);
 
             if ( exists $self->emotion->wordlist->{$word} ) {
+                $known++;
+
                 for my $key ( keys %{ $self->emotion->wordlist->{$word} } ) {
                     $score->{$key} += $self->emotion->wordlist->{$word}{$key};
                 }
             }
+            else {
+                $unknown++;
+            }
         }
 
         $score = $null_state
@@ -175,6 +200,8 @@ sub nrc_sentiment {
         push @scores, $score;
     }
 
+    $self->familiarity( { known => $known, unknown => $unknown } );
+
     $self->nrc_scores( \@scores );
 }
 
@@ -278,7 +305,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1301
+version 0.1400
 
 =head1 SYNOPSIS
 
@@ -290,6 +317,8 @@ version 0.1301
   my $score = $opinion->averaged_score(5);
   my $sentiment = $opinion->get_word('foo');
   $sentiment = $opinion->get_sentence('Mary had a little lamb.');
+  my $total = $opinion->familiarity->{known} + $opinion->familiarity->{unknown};
+  print $opinion->familiarity->{known} / $total, "\n";
 
   # Also:
   $opinion = Lingua::EN::Opinion->new( text => 'Mary had a little lamb...' );
@@ -360,6 +389,12 @@ Computed result.
 
 Computed result.
 
+=head2 familiarity
+
+Computed result.  Hash reference of total words:
+
+ { known => $x, unknown => $y }
+
 =head1 METHODS
 
 =head2 new()
@@ -459,7 +494,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
